==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/uk.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "На даному сервері вимкнута можливість передачі даних між серверами",
    "The mountpoint name contains invalid characters." : "Ім’я точки монтування містить неприпустимі символи.",
    "Invalid or untrusted SSL certificate" : "Недійсній або не довірений SSL-сертифікат",
    "Could not authenticate to remote share, password might be wrong" : "Не вдалося провести аутентифікацію для доступу до віддаленого сховища, можливо неправильно вказано пароль",
    "Storage not valid" : "Cховище недоступне",
    "Couldn't add remote share" : "Неможливо додати віддалену загальну теку",
    "Shared with you" : "Доступне для вас",
    "Shared with others" : "Доступне для інших",
    "Shared by link" : "Доступне за посиланням",
    "Uploading..." : "Вивантаження...",
    "Nothing shared with you yet" : "Ніхто з вами ще не поділився файлами",
    "Files and folders others share with you will show up here" : "Розшарені для вас файли і папки з’являться тут",
    "Nothing shared yet" : "Немає нічого розшареного",
    "Files and folders you share will show up here" : "Файли і папки, які розшарені вами відображатимуться тут",
    "No shared links" : "Немає опублікованих посилань",
    "Files and folders you share by link will show up here" : "Файли і папки, якими ви поділилися за посиланням будуть відображатися тут",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалену загальну теку {name} з {owner}@{remote}?",
    "Remote share" : "Віддалена загальна тека",
    "Remote share password" : "Пароль для віддаленої загальної теки",
    "Cancel" : "Відмінити",
    "Add remote share" : "Додати віддалену загальну теку",
    "You can upload into this folder" : "Ви можете завантажити до цієї теки",
    "No ownCloud installation (7 or higher) found at {remote}" : "Немає установленого OwnCloud (7 або вище), можна знайти на {remote}",
    "Invalid ownCloud url" : "Невірний ownCloud URL",
    "Share" : "Поділитися",
    "Shared by" : "Опубліковано",
    "Sharing" : "Спільний доступ",
    "A file or folder has been <strong>shared</strong>" : "Файл або теку було відкрито для <strong> спільного користування </strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файл або каталог був опублікований <strong>з іншого сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Опублікований файл або каталог  був <strong>завантажений</strong>",
    "You received a new remote share from %s" : "Ви отримали нову віддалену папку %s",
    "%1$s accepted remote share %2$s" : "%1$s віддалена шара підтверджена %2$s",
    "%1$s declined remote share %2$s" : "%1$s віддалена шара скасована %2$s",
    "%1$s unshared %2$s from you" : "%1$s не розшарений %2$s для вас",
    "Public shared folder %1$s was downloaded" : "Опублікований каталог %1$s був завантажений",
    "Public shared file %1$s was downloaded" : "Загальнодоступний файл %1$s був завантажений",
    "You shared %1$s with %2$s" : "Ви поділилися %1$s з %2$s",
    "You shared %1$s with group %2$s" : "Ви поділилися %1$s з групою %2$s",
    "You shared %1$s via link" : "Ви поділилися %1$s використовуючи лінк",
    "%2$s shared %1$s with you" : "%2$s поділився %1$s з вами",
    "Shares" : "Розподільні",
    "This share is password-protected" : "Цей ресурс обміну захищений паролем",
    "The password is wrong. Try again." : "Невірний пароль. Спробуйте ще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Записів не знайдено в цій папці",
    "Name" : "Ім’я",
    "Share time" : "Дата публікації",
    "Expiration date" : "Термін дії",
    "Sorry, this link doesn’t seem to work anymore." : "На жаль, посилання більше не працює.",
    "Reasons might be:" : "Можливі причини:",
    "the item was removed" : "цей пункт був вилучений",
    "the link expired" : "посилання застаріло",
    "sharing is disabled" : "обмін заборонений",
    "For more info, please ask the person who sent this link." : "Для отримання додаткової інформації, будь ласка, зверніться до особи, яка надіслала це посилання.",
    "Add to your ownCloud" : "Додати до вашого ownCloud",
    "Download" : "Завантажити",
    "Download %s" : "Завантажити %s",
    "Direct link" : "Пряме посилання"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/uk.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "На даному сервері вимкнута можливість передачі даних між серверами",
    "The mountpoint name contains invalid characters." : "Ім’я точки монтування містить неприпустимі символи.",
    "Invalid or untrusted SSL certificate" : "Недійсній або не довірений SSL-сертифікат",
    "Could not authenticate to remote share, password might be wrong" : "Не вдалося провести аутентифікацію для доступу до віддаленого сховища, можливо неправильно вказано пароль",
    "Storage not valid" : "Cховище недоступне",
    "Couldn't add remote share" : "Неможливо додати віддалену загальну теку",
    "Shared with you" : "Доступне для вас",
    "Shared with others" : "Доступне для інших",
    "Shared by link" : "Доступне за посиланням",
    "Uploading..." : "Вивантаження...",
    "Nothing shared with you yet" : "Ніхто з вами ще не поділився файлами",
    "Files and folders others share with you will show up here" : "Розшарені для вас файли і папки з’являться тут",
    "Nothing shared yet" : "Немає нічого розшареного",
    "Files and folders you share will show up here" : "Файли і папки, які розшарені вами відображатимуться тут",
    "No shared links" : "Немає опублікованих посилань",
    "Files and folders you share by link will show up here" : "Файли і папки, якими ви поділилися за посиланням будуть відображатися тут",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалену загальну теку {name} з {owner}@{remote}?",
    "Remote share" : "Віддалена загальна тека",
    "Remote share password" : "Пароль для віддаленої загальної теки",
    "Cancel" : "Відмінити",
    "Add remote share" : "Додати віддалену загальну теку",
    "You can upload into this folder" : "Ви можете завантажити до цієї теки",
    "No ownCloud installation (7 or higher) found at {remote}" : "Немає установленого OwnCloud (7 або вище), можна знайти на {remote}",
    "Invalid ownCloud url" : "Невірний ownCloud URL",
    "Share" : "Поділитися",
    "Shared by" : "Опубліковано",
    "Sharing" : "Спільний доступ",
    "A file or folder has been <strong>shared</strong>" : "Файл або теку було відкрито для <strong> спільного користування </strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файл або каталог був опублікований <strong>з іншого сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Опублікований файл або каталог  був <strong>завантажений</strong>",
    "You received a new remote share from %s" : "Ви отримали нову віддалену папку %s",
    "%1$s accepted remote share %2$s" : "%1$s віддалена шара підтверджена %2$s",
    "%1$s declined remote share %2$s" : "%1$s віддалена шара скасована %2$s",
    "%1$s unshared %2$s from you" : "%1$s не розшарений %2$s для вас",
    "Public shared folder %1$s was downloaded" : "Опублікований каталог %1$s був завантажений",
    "Public shared file %1$s was downloaded" : "Загальнодоступний файл %1$s був завантажений",
    "You shared %1$s with %2$s" : "Ви поділилися %1$s з %2$s",
    "You shared %1$s with group %2$s" : "Ви поділилися %1$s з групою %2$s",
    "You shared %1$s via link" : "Ви поділилися %1$s використовуючи лінк",
    "%2$s shared %1$s with you" : "%2$s поділився %1$s з вами",
    "Shares" : "Розподільні",
    "This share is password-protected" : "Цей ресурс обміну захищений паролем",
    "The password is wrong. Try again." : "Невірний пароль. Спробуйте ще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Записів не знайдено в цій папці",
    "Name" : "Ім’я",
    "Share time" : "Дата публікації",
    "Expiration date" : "Термін дії",
    "Sorry, this link doesn’t seem to work anymore." : "На жаль, посилання більше не працює.",
    "Reasons might be:" : "Можливі причини:",
    "the item was removed" : "цей пункт був вилучений",
    "the link expired" : "посилання застаріло",
    "sharing is disabled" : "обмін заборонений",
    "For more info, please ask the person who sent this link." : "Для отримання додаткової інформації, будь ласка, зверніться до особи, яка надіслала це посилання.",
    "Add to your ownCloud" : "Додати до вашого ownCloud",
    "Download" : "Завантажити",
    "Download %s" : "Завантажити %s",
    "Direct link" : "Пряме посилання",
    "Pending" : "Очікування",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
